@@ -42,7 +42,7 @@ class Selection:
         """Returns an array of SelectionItems turned into dicts"""
         array = []
         for item in self.items:
-            array.append(dict(item))
+            array.append(item.jsonify())
         return array
 
     def exists(self) -> bool:
@@ -50,9 +50,17 @@ class Selection:
             return True
         return False
 
-    def order_by(self, key=None, reverse=False):
-        return sorted(
-            self.items, key=lambda x: getattr(x, key), reverse=reverse)
+    def order_by(self, key=None, reverse=False, case=False):
+        if case:
+            return Selection(*sorted(
+                self.items, key=lambda x: getattr(x, key), reverse=reverse))
+        else:
+            return Selection(*sorted(
+                self.items, key=lambda x: getattr(
+                    x, key).upper(), reverse=reverse))
+
+    def filter(self, func):
+        return Selection(*filter(func, self.items))
 
 
 class SelectionItem:
